import * as dynamodb from 'aws-cdk-lib/aws-dynamodb';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as sqs from 'aws-cdk-lib/aws-sqs';
import { Construct } from 'constructs';
export interface SFExecutionsStartThrottleProps {
    /** Executions concurrency, default is 100
     * should be set to whatever the bottleneck of the workflow is
     * For Textract Asynchronous APIs, that would be the number of concurrent jobs that can be processed
     * For Textract Synchronous APIs, that would be the TPS for the API
    */
    readonly executionsConcurrencyThreshold?: number;
    /** State Machine ARN */
    readonly stateMachineArn: string;
    /** Status table - DynamoDB table with status information for the document execution */
    readonly documentStatusTable?: dynamodb.ITable;
    /** Step Functions Executions Counter - DynamoDB table with current count of executions */
    readonly executionsCounterTable?: dynamodb.ITable;
    /** List of PolicyStatements to attach to the Lambda function.  */
    readonly inputPolicyStatements?: iam.PolicyStatement[];
    /** SQS Batch size when catchup up on queued documents (max 10, which is also the default) */
    readonly sqsBatch?: number;
    /** List of PolicyStatements to attach to the Lambda function.  */
    readonly eventSource?: lambda.IEventSource[];
    /** log level for Lambda function, supports DEBUG|INFO|WARNING|ERROR|FATAL
     * @default = INFO
     */
    readonly lambdaLogLevel?: 'DEBUG' | 'INFO' | 'WARNING' | 'ERROR' | 'FATAL';
    /** Lambda Function Timeout in seconds, default 300 */
    readonly lambdaTimeout?: number;
    /** Memory allocated to Lambda function, default 512 */
    readonly lambdaMemory?: number;
    /** log level for Lambda function, supports DEBUG|INFO|WARNING|ERROR|FATAL
     * @default = DEBUG
     */
    readonly lambdaQueueWorkerLogLevel?: 'DEBUG' | 'INFO' | 'WARNING' | 'ERROR' | 'FATAL';
    /** Lambda Function Timeout in seconds, default 300 */
    readonly lambdaQueueWorkerTimeout?: number;
    /** Memory allocated to Lambda function, default 512 */
    readonly lambdaQueueWorkerMemory?: number;
    /** Bucketname and prefix to read document from
    /** location of input S3 objects - if left empty will generate rule for s3 access to all [*] */
    readonly s3InputBucket?: string;
    /** prefix for input S3 objects - if left empty will generate rule for s3 access to all in bucket */
    readonly s3InputPrefix?: string;
}
/**
 * This construct starts State Machine executions based on events, but limits the number of concurrent running executions to a threshold number
 * - S3
 * - API Gateway
 * - SQS
 *
 * This version does not yet support passing in a manifest for configuration of Textract features. That will be a future enhancement.
 * The following resources are created:
 * - Lambda function
 * - DynamoDB table. For every document pass in an entry in a DynamoDB table is created with a status (RECEIVED, QUEUED, IN_PROGRESS)
 *
 */
export declare class SFExecutionsStartThrottle extends Construct {
    executionsStartThrottleFunction: lambda.IFunction;
    executionsThrottleCounterResetFunction: lambda.IFunction;
    executionsQueueWorkerFunction: lambda.IFunction;
    documentStatusTable?: dynamodb.ITable;
    documentQueue?: sqs.IQueue;
    executionsCounterTable?: dynamodb.ITable;
    constructor(parent: Construct, id: string, props: SFExecutionsStartThrottleProps);
}
